@@ -462,6 +462,7 @@ impl Cli {
 
                 let register_cluster = RegisterCluster::new(
                     helm,
+                    provider,
                     namespace,
                     states,
                     default_state,
@@ -472,15 +473,15 @@ impl Cli {
                     // Right now interactive_register_cluster() does very much the same job as
                     // non-interactive counterpart. In the future we may handle it differently.
                     statehub
-                        .interactive_register_cluster(names, kubectl, provider, register_cluster)
+                        .interactive_register_cluster(names, kubectl, register_cluster)
                         .await
                 } else if names.is_empty() {
                     statehub
-                        .register_single_cluster(kubectl, provider, register_cluster)
+                        .register_cluster_from_current_context(kubectl, register_cluster)
                         .await
                 } else {
                     statehub
-                        .register_multiple_clusters(names, kubectl, provider, register_cluster)
+                        .register_multiple_clusters(names, kubectl, register_cluster)
                         .await
                 }
             }
@@ -677,22 +678,20 @@ impl StateHub {
         &self,
         names: Vec<v0::ClusterName>,
         kubectl: k8s::Kubectl,
-        provider: Option<v0::Provider>,
         register_cluster: RegisterCluster,
     ) -> anyhow::Result<()> {
         if names.is_empty() {
-            self.register_single_cluster(kubectl, provider, register_cluster)
+            self.register_cluster_from_current_context(kubectl, register_cluster)
                 .await
         } else {
-            self.register_multiple_clusters(names, kubectl, provider, register_cluster)
+            self.register_multiple_clusters(names, kubectl, register_cluster)
                 .await
         }
     }
 
-    async fn register_single_cluster(
+    async fn register_cluster_from_current_context(
         &self,
         kubectl: k8s::Kubectl,
-        provider: Option<v0::Provider>,
         register_cluster: RegisterCluster,
     ) -> anyhow::Result<()> {
         let locations = kubectl.collect_node_locations().await?;
@@ -703,7 +702,7 @@ impl StateHub {
             self.verbosely("Skip adding this cluster to any state")?;
         }
 
-        self.register_cluster_helper(kubectl, provider, &locations, register_cluster)
+        self.register_cluster_helper(kubectl, &locations, register_cluster)
             .await
     }
 
@@ -711,7 +710,6 @@ impl StateHub {
         &self,
         names: Vec<v0::ClusterName>,
         kubectl: k8s::Kubectl,
-        provider: Option<v0::Provider>,
         register_cluster: RegisterCluster,
     ) -> anyhow::Result<()> {
         let mut clusters = indexmap::indexmap!();
@@ -738,7 +736,7 @@ impl StateHub {
         }
 
         for (locations, kubectl) in clusters {
-            self.register_cluster_helper(kubectl, provider, &locations, register_cluster.clone())
+            self.register_cluster_helper(kubectl, &locations, register_cluster.clone())
                 .await?;
         }
 
