@@ -13,7 +13,7 @@ use crate::k8s;
 use super::*;
 
 impl Cluster {
-    const CLUSTER: Emoji<'static, 'static> = Emoji("☸", "*");
+    const CLUSTER: Emoji<'static, 'static> = Emoji("☸️", "*");
 
     pub(crate) fn all_locations(&self) -> Vec<Location> {
         let aws = self.locations.aws.iter().map(|aws| aws.region.into());
